@@ -40,7 +40,7 @@
 #include "gnc-splash.h"
 #include "gnc-window.h"
 #include "gnc-icons.h"
-#include "dialog-assoc-utils.h"
+#include "dialog-doclink-utils.h"
 #include "dialog-options.h"
 #include "dialog-commodity.h"
 #include "dialog-totd.h"
@@ -90,13 +90,13 @@ gnc_gnome_utils_init (void)
 static void
 gnc_global_options_help_cb (GNCOptionWin *win, gpointer dat)
 {
-    gnc_gnome_help (HF_HELP, HL_GLOBPREFS);
+    gnc_gnome_help (GTK_WINDOW(gnc_options_dialog_widget (win)), HF_HELP, HL_GLOBPREFS);
 }
 
 static void
 gnc_book_options_help_cb (GNCOptionWin *win, gpointer dat)
 {
-    gnc_gnome_help (HF_HELP, HL_BOOK_OPTIONS);
+    gnc_gnome_help (GTK_WINDOW(gnc_options_dialog_widget (win)), HF_HELP, HL_BOOK_OPTIONS);
 }
 
 void
@@ -131,9 +131,17 @@ gnc_options_dialog_set_new_book_option_values (GNCOptionDB *odb)
 }
 
 static void
-gnc_commodity_help_cb (void)
+gnc_style_sheet_options_help_cb (GNCOptionWin *win, gpointer dat)
 {
-    gnc_gnome_help (HF_HELP, HL_COMMODITY);
+    gnc_gnome_help (GTK_WINDOW(gnc_options_dialog_widget (win)), HF_HELP, HL_STYLE_SHEET);
+}
+
+void
+gnc_options_dialog_set_style_sheet_options_help_cb (GNCOptionWin *win)
+{
+    gnc_options_dialog_set_help_cb (win,
+                                   (GNCOptionWinCallback)gnc_style_sheet_options_help_cb,
+                                    NULL);
 }
 
 /* gnc_configure_date_format
@@ -222,6 +230,64 @@ gnc_add_css_file (void)
     g_object_unref (provider_fallback);
 }
 
+/* This function fixes an issue with yelp that it does not work with the
+ * ?anchor variant, see https://gitlab.gnome.org/GNOME/yelp/issues/116
+ */
+static gchar *
+gnc_gnome_help_yelp_anchor_fix (GtkWindow *parent, const char *file_name, const char *anchor)
+{
+    const gchar * const *sdatadirs = g_get_system_data_dirs ();
+    const gchar * const *langs = g_get_language_names ();
+    gchar *lookfor = g_strconcat ("gnome/help/", file_name, NULL);
+    gchar *help_path = NULL;
+    gchar *help_file = NULL;
+    gchar *full_path = NULL;
+    gchar *uri = NULL;
+
+    for (; *sdatadirs; sdatadirs++)
+    {
+        gchar *filepath = g_build_filename (*sdatadirs, lookfor, NULL);
+        if (g_file_test (filepath, G_FILE_TEST_EXISTS))
+            help_path = g_strdup (filepath);
+        g_free (filepath);
+    }
+    g_free (lookfor);
+
+    if (!help_path)
+    {
+        gnc_error_dialog (parent, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
+        PERR("Unable to find 'gnome/help' directory");
+        return NULL;
+    }
+
+    // add the file extension, currently .xml
+    help_file = g_strconcat (file_name, ".xml", NULL);
+
+    for (; *langs; langs++)
+    {
+        gchar *filename = g_build_filename (help_path, *langs, help_file, NULL);
+        if (g_file_test (filename, G_FILE_TEST_EXISTS))
+        {
+            full_path = filename;
+            break;
+        }
+        g_free (filename);
+    }
+    g_free (help_path);
+    g_free (help_file);
+
+    if (full_path)
+        uri = g_strconcat ("ghelp:", full_path, "?", anchor, NULL);
+    else
+    {
+        gnc_error_dialog (parent, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
+        PERR("Unable to find valid help language directory");
+        return NULL;
+    }
+    g_free (full_path);
+    return uri;
+}
+
 #ifdef MAC_INTEGRATION
 
 /* Don't be alarmed if this function looks strange to you: It's
@@ -229,7 +295,7 @@ gnc_add_css_file (void)
  * toolkit.
  */
 void
-gnc_gnome_help (const char *dir, const char *detail)
+gnc_gnome_help (GtkWindow *parent, const char *dir, const char *detail)
 {
     NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
     NSString *subdir = [NSString stringWithUTF8String: dir];
@@ -270,9 +336,9 @@ gnc_gnome_help (const char *dir, const char *detail)
                   componentsJoinedByString: @"-"];
         if (![[NSFileManager defaultManager] fileExistsAtPath: docs_dir])
         {
-            gnc_error_dialog(NULL, "%s\n%s\n%s: %s", _(msg_no_help_found),
-                             _(msg_no_help_reason),
-                             _(msg_no_help_location), [docs_dir UTF8String]);
+            gnc_error_dialog (parent, "%s\n%s\n%s: %s", _(msg_no_help_found),
+                              _(msg_no_help_reason),
+                              _(msg_no_help_location), [docs_dir UTF8String]);
             [pool release];
             return;
         }
@@ -362,13 +428,13 @@ gnc_gnome_help (const char *dir, const char *detail)
         [[NSWorkspace sharedWorkspace] openURL: url];
     else
     {
-       gnc_error_dialog(NULL, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
+       gnc_error_dialog (parent, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
     }
     [pool release];
 }
 #elif defined G_OS_WIN32 /* G_OS_WIN32 */
 void
-gnc_gnome_help (const char *file_name, const char *anchor)
+gnc_gnome_help (GtkWindow *parent, const char *file_name, const char *anchor)
 {
     const gchar * const *lang;
     gchar *pkgdatadir, *fullpath, *found = NULL;
@@ -390,7 +456,7 @@ gnc_gnome_help (const char *file_name, const char *anchor)
 
     if (!found)
     {
-        gnc_error_dialog (NULL, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
+        gnc_error_dialog (parent, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
     }
     else
     {
@@ -400,20 +466,21 @@ gnc_gnome_help (const char *file_name, const char *anchor)
 }
 #else
 void
-gnc_gnome_help (const char *file_name, const char *anchor)
+gnc_gnome_help (GtkWindow *parent, const char *file_name, const char *anchor)
 {
     GError *error = NULL;
     gchar *uri = NULL;
-    gboolean success;
+    gboolean success = TRUE;
 
     if (anchor)
-        uri = g_strconcat ("ghelp:", file_name, "?", anchor, NULL);
+        uri = gnc_gnome_help_yelp_anchor_fix (parent, file_name, anchor);
     else
         uri = g_strconcat ("ghelp:", file_name, NULL);
 
     DEBUG ("Attempting to opening help uri %s", uri);
 
-    success = gtk_show_uri_on_window (NULL, uri, gtk_get_current_event_time (), &error);
+    if (uri)
+        success = gtk_show_uri_on_window (NULL, uri, gtk_get_current_event_time (), &error);
 
     g_free (uri);
     if (success)
@@ -421,7 +488,7 @@ gnc_gnome_help (const char *file_name, const char *anchor)
 
     g_assert(error != NULL);
     {
-        gnc_error_dialog(NULL, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
+        gnc_error_dialog (parent, "%s\n%s", _(msg_no_help_found), _(msg_no_help_reason));
     }
     PERR ("%s", error->message);
     g_error_free(error);
@@ -437,13 +504,13 @@ gnc_gnome_help (const char *file_name, const char *anchor)
  * toolkit.
  */
 void
-gnc_launch_assoc (GtkWindow *parent, const char *uri)
+gnc_launch_doclink (GtkWindow *parent, const char *uri)
 {
     NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
     NSString *uri_str = [NSString stringWithUTF8String: uri];
     NSURL *url = [[[NSURL alloc] initWithString: uri_str] autorelease];
     const gchar *message =
-        _("GnuCash could not find the associated file.");
+        _("GnuCash could not find the linked document.");
 
     if (url)
     {
@@ -459,7 +526,7 @@ gnc_launch_assoc (GtkWindow *parent, const char *uri)
 }
 #elif defined G_OS_WIN32 /* G_OS_WIN32 */
 void
-gnc_launch_assoc (GtkWindow *parent, const char *uri)
+gnc_launch_doclink (GtkWindow *parent, const char *uri)
 {
     wchar_t *winuri = NULL;
     gchar *filename = NULL;
@@ -468,7 +535,7 @@ gnc_launch_assoc (GtkWindow *parent, const char *uri)
     if (gnc_uri_is_file_uri (uri))
     {
         gchar *uri_scheme = gnc_uri_get_scheme (uri);
-        filename = gnc_assoc_get_unescape_uri (NULL, uri, uri_scheme);
+        filename = gnc_doclink_get_unescape_uri (NULL, uri, uri_scheme);
         winuri = (wchar_t *)g_utf8_to_utf16(filename, -1, NULL, NULL, NULL);
         g_free (uri_scheme);
     }
@@ -483,7 +550,7 @@ gnc_launch_assoc (GtkWindow *parent, const char *uri)
                        NULL, NULL, SW_SHOWNORMAL) <= 32)
         {
             const gchar *message =
-            _("GnuCash could not find the associated file.");
+            _("GnuCash could not find the linked document.");
             gnc_error_dialog (parent, "%s:\n%s", message, filename);
         }
         g_free (wincmd);
@@ -494,7 +561,7 @@ gnc_launch_assoc (GtkWindow *parent, const char *uri)
 
 #else
 void
-gnc_launch_assoc (GtkWindow *parent, const char *uri)
+gnc_launch_doclink (GtkWindow *parent, const char *uri)
 {
     GError *error = NULL;
     gboolean success;
@@ -513,12 +580,12 @@ gnc_launch_assoc (GtkWindow *parent, const char *uri)
     {
         gchar *error_uri = NULL;
         const gchar *message =
-            _("GnuCash could not open the associated file:");
+            _("GnuCash could not open the linked document:");
 
         if (gnc_uri_is_file_uri (uri))
         {
             gchar *uri_scheme = gnc_uri_get_scheme (uri);
-            error_uri = gnc_assoc_get_unescape_uri (NULL, uri, uri_scheme);
+            error_uri = gnc_doclink_get_unescape_uri (NULL, uri, uri_scheme);
             g_free (uri_scheme);
         }
         else
@@ -703,7 +770,6 @@ gnc_gui_init(void)
                                 gnc_gui_refresh_all,
                                 NULL);
 
-    gnc_ui_commodity_set_help_callback (gnc_commodity_help_cb);
     gnc_file_set_shutdown_callback (gnc_shutdown);
 
     gnc_options_dialog_set_global_help_cb (gnc_global_options_help_cb, NULL);
