@@ -35,7 +35,11 @@
 #include <gwenhywfar/gwenhywfar.h>
 #include <aqbanking/banking.h>
 #ifdef AQBANKING6
-# include <aqbanking/types/balance.h>
+#include <aqbanking/types/balance.h>
+#if (AQBANKING_VERSION_INT >= 60400)
+#include <aqbanking/types/refaccount.h>
+#include <gnc-aqbanking-templates.h>
+#endif
 #endif
 #include "window-reconcile.h"
 #include "Transaction.h"
@@ -99,7 +103,8 @@ gnc_gwen_date_to_time64 (const GNC_GWEN_DATE* date)
 #else
     int month, day, year;
     GWEN_Time_GetBrokenDownDate(date, &day, &month, &year);
-    return gnc_dmy2time64_neutral(day, month, year);
+    /* GWEN_Time_GetBrokenDownDate returns localtime(3) format; month is [0..11] */
+    return gnc_dmy2time64_neutral(day, month + 1, year);
 #endif
 }
 
@@ -191,18 +196,18 @@ gnc_AB_BANKING_new(void)
         {
             if (AB_Banking_HasConf3(api) == 0)
             {
-                g_message("gnc_AB_BANKING_new: importing aqbanking3 configuration\n");
+                PINFO("gnc_AB_BANKING_new: importing aqbanking3 configuration\n");
                 if (AB_Banking_ImportConf3(api) < 0)
                 {
-                    g_message("gnc_AB_BANKING_new: unable to import aqbanking3 configuration\n");
+                    PINFO("gnc_AB_BANKING_new: unable to import aqbanking3 configuration\n");
                 }
             }
             else if (AB_Banking_HasConf2(api) == 0)
             {
-                g_message("gnc_AB_BANKING_new: importing aqbanking2 configuration\n");
+                PINFO("gnc_AB_BANKING_new: importing aqbanking2 configuration\n");
                 if (AB_Banking_ImportConf2(api) < 0)
                 {
-                    g_message("gnc_AB_BANKING_new: unable to import aqbanking2 configuration\n");
+                    PINFO("gnc_AB_BANKING_new: unable to import aqbanking2 configuration\n");
                 }
             }
         }
@@ -290,7 +295,7 @@ gnc_ab_get_ab_account(const AB_BANKING *api, Account *gnc_acc)
 /* Finding the account by code and number is suspended in AQBANKING 6 pending
  * implementation of a replacement for AB_Banking_GetAccountByCodeAndNumber.
  */
-            g_message("gnc_ab_get_ab_account: No AB_ACCOUNT found for UID %d, "
+            PINFO("gnc_ab_get_ab_account: No AB_ACCOUNT found for UID %d, "
                       "trying bank code\n", account_uid);
             return NULL;
         }
@@ -300,7 +305,7 @@ gnc_ab_get_ab_account(const AB_BANKING *api, Account *gnc_acc)
 
         if (!ab_account && bankcode && *bankcode && accountid && *accountid)
         {
-            g_message("gnc_ab_get_ab_account: No AB_ACCOUNT found for UID %d, "
+            PINFO("gnc_ab_get_ab_account: No AB_ACCOUNT found for UID %d, "
                       "trying bank code\n", account_uid);
             ab_account = AB_Banking_GetAccountByCodeAndNumber(api, bankcode,
                                                               accountid);
@@ -796,7 +801,7 @@ txn_transaction_cb(const AB_TRANSACTION *element, gpointer user_data)
             if (gnc_verify_dialog(
                         GTK_WINDOW (data->parent), FALSE, "%s",
                         _("The backend found an error during the preparation "
-                          "of the job. It is not possible to execute this job. \n"
+                          "of the job. It is not possible to execute this job.\n"
                           "\n"
                           "Most probably the bank does not support your chosen "
                           "job or your Online Banking account does not have the permission "
@@ -1032,16 +1037,18 @@ bal_accountinfo_cb(AB_IMEXPORTER_ACCOUNTINFO *element, gpointer user_data)
 
     if (!(data->awaiting & AWAIT_BALANCES))
     {
+         GtkWindow *parent = data->generic_importer ?
+              GTK_WINDOW(data->generic_importer) :
+              GTK_WINDOW(data->parent);
+         const char* balance_msg =
+              _("The bank has sent balance information in its response.\n"
+                "Do you want to import it?");
         /* Ignore zero balances if we don't await a balance */
         if (!booked_bal || AB_Value_IsZero(AB_Balance_GetValue(booked_bal)))
             return NULL;
 
         /* Ask the user whether to import unawaited non-zero balance */
-        if (gnc_verify_dialog (GTK_WINDOW (data->parent), TRUE, "%s",
-                              _("The bank has sent balance information "
-                                "in its response."
-                                "\n"
-                                "Do you want to import it?")))
+        if (gnc_verify_dialog (parent, TRUE, "%s", balance_msg))
         {
             data->awaiting |= AWAIT_BALANCES;
         }
@@ -1129,12 +1136,12 @@ bal_accountinfo_cb(AB_IMEXPORTER_ACCOUNTINFO *element, gpointer user_data)
                      GTK_BUTTONS_OK,
                      "%s",
                      /* Translators: Strings from this file are needed only in
-                      * countries that have one of aqbanking's Online Banking
-                      * techniques available. This is 'OFX DirectConnect'
-                      * (U.S. and others), 'HBCI' (in Germany), or 'YellowNet'
-                      * (Switzerland). If none of these techniques are available
-                      * in your country, you may safely ignore strings from the
-                      * import-export/hbci subdirectory. */
+                        countries that have one of aqbanking's Online Banking
+                        techniques available. This is 'OFX DirectConnect'
+                        (U.S. and others), 'HBCI' (in Germany), or 'YellowNet'
+                        (Switzerland). If none of these techniques are available
+                        in your country, you may safely ignore strings from the
+                        import-export/hbci subdirectory. */
                      _("The downloaded Online Banking Balance was zero.\n\n"
                        "Either this is the correct balance, or your bank does not "
                        "support Balance download in this Online Banking version. "
@@ -1152,7 +1159,7 @@ bal_accountinfo_cb(AB_IMEXPORTER_ACCOUNTINFO *element, gpointer user_data)
 
         gchar *booked_str = gnc_AB_VALUE_to_readable_string(booked_val);
         gchar *message1 = g_strdup_printf(
-                              _("Result of Online Banking job: \n"
+                              _("Result of Online Banking job:\n"
                                 "Account booked balance is %s"),
                               booked_str);
         gchar *message2 =
@@ -1243,6 +1250,10 @@ gnc_ab_import_context(AB_IMEXPORTER_CONTEXT *context,
             AB_ImExporterAccountInfo_List_ForEach(ab_ail, txn_accountinfo_cb,
                                                   data);
 
+        /* populate and display the matching window */
+        if (data->generic_importer)
+            gnc_gen_trans_list_show_all(data->generic_importer);
+
         /* Check balances */
         if (!(awaiting & IGNORE_BALANCES))
             AB_ImExporterAccountInfo_List_ForEach(ab_ail, bal_accountinfo_cb,
@@ -1253,6 +1264,10 @@ gnc_ab_import_context(AB_IMEXPORTER_CONTEXT *context,
         AB_ImExporterContext_AccountInfoForEach(context, txn_accountinfo_cb,
                                                 data);
 
+    /* populate and display the matching window */
+    if (data->generic_importer)
+        gnc_gen_trans_list_show_all(data->generic_importer);
+
     /* Check balances */
     if (!(awaiting & IGNORE_BALANCES))
         AB_ImExporterContext_AccountInfoForEach(context, bal_accountinfo_cb,
@@ -1320,3 +1335,46 @@ gnc_ab_get_permanent_certs(void)
     g_return_val_if_fail(rv >= 0, NULL);
     return perm_certs;
 }
+
+#if (AQBANKING_VERSION_INT >= 60400)
+GList*
+gnc_ab_trans_templ_list_new_from_ref_accounts(GNC_AB_ACCOUNT_SPEC *ab_acc)
+{
+    GList *retval = NULL;
+    AB_REFERENCE_ACCOUNT *ra;
+    AB_REFERENCE_ACCOUNT_LIST *ral;
+    GWEN_BUFFER *accNameForTemplate = GWEN_Buffer_new(0,120,0,0);
+    gnc_numeric zero = gnc_numeric_zero();
+
+    /* get the target account list */
+    ral = AB_AccountSpec_GetRefAccountList(ab_acc);
+    ra = AB_ReferenceAccount_List_First(ral);
+    
+    /* fill the template list with the target accounts */
+    while (ra)
+    {
+        GncABTransTempl *new_templ = gnc_ab_trans_templ_new();
+        const char *iban = AB_ReferenceAccount_GetIban(ra);
+	const char *accName = AB_ReferenceAccount_GetAccountName(ra);
+	GWEN_Buffer_Reset(accNameForTemplate);
+	if (accName)
+	{
+	    GWEN_Buffer_AppendString(accNameForTemplate, accName);
+	    GWEN_Buffer_AppendString(accNameForTemplate, ": ");
+	}
+	GWEN_Buffer_AppendString(accNameForTemplate, iban);
+	gnc_ab_trans_templ_set_name(new_templ, GWEN_Buffer_GetStart(accNameForTemplate));
+	gnc_ab_trans_templ_set_recp_name(new_templ, AB_ReferenceAccount_GetOwnerName(ra));
+	gnc_ab_trans_templ_set_recp_account(new_templ, AB_ReferenceAccount_GetIban(ra));
+	gnc_ab_trans_templ_set_recp_bankcode(new_templ, AB_ReferenceAccount_GetBic(ra));
+	gnc_ab_trans_templ_set_amount(new_templ, zero);
+	retval = g_list_prepend (retval, new_templ);
+	ra = AB_ReferenceAccount_List_Next(ra);
+    }
+    retval = g_list_reverse (retval);
+
+    GWEN_Buffer_free(accNameForTemplate);
+
+    return retval;
+}
+#endif
