@@ -512,6 +512,7 @@ CsvImpTransAssist::CsvImpTransAssist ()
         // Add Settings combo
         auto settings_store = gtk_list_store_new (2, G_TYPE_POINTER, G_TYPE_STRING);
         settings_combo = GTK_COMBO_BOX(gtk_combo_box_new_with_model_and_entry (GTK_TREE_MODEL(settings_store)));
+        g_object_unref (settings_store);
         gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX(settings_combo), SET_NAME);
         gtk_combo_box_set_active (GTK_COMBO_BOX(settings_combo), 0);
 
@@ -902,7 +903,7 @@ CsvImpTransAssist::preview_settings_save ()
             {
                 auto response = gnc_ok_cancel_dialog (GTK_WINDOW (csv_imp_asst),
                         GTK_RESPONSE_OK,
-                        "%s", _("Setting name already exists, over write?"));
+                        "%s", _("Setting name already exists, overwrite?"));
                 if (response != GTK_RESPONSE_OK)
                     return;
 
@@ -1571,9 +1572,7 @@ void CsvImpTransAssist::preview_refresh_table ()
 
     /* Start with counting the current number of columns (ntcols)
      * we have in the treeview */
-    auto columns = gtk_tree_view_get_columns (treeview);
-    auto ntcols = g_list_length(columns);
-    g_list_free (columns);
+    auto ntcols = gtk_tree_view_get_n_columns (treeview);
 
     /* Drop redundant columns if the model has less data columns than the new model
      * ntcols = n° of columns in treeview (1 error column + x data columns)
@@ -2084,7 +2083,7 @@ CsvImpTransAssist::assist_match_page_prepare ()
     else
     {
         // align the help button on the left side
-        gtk_widget_set_halign (GTK_WIDGET(button_area), GTK_ALIGN_FILL);  
+        gtk_widget_set_halign (GTK_WIDGET(button_area), GTK_ALIGN_FILL);
         gtk_widget_set_hexpand (GTK_WIDGET(button_area), TRUE);
         gtk_box_set_child_packing (GTK_BOX(button_area), help_button,
                                    FALSE, FALSE, 0, GTK_PACK_START);
