@@ -130,7 +130,8 @@ static void gnc_gen_trans_assign_transfer_account_to_selection_cb (GtkMenuItem *
                                                                    GNCImportMainMatcher *info);
 static void gnc_gen_trans_view_popup_menu (GtkTreeView *treeview,
                                            GdkEvent *event,
-                                           GNCImportMainMatcher *info);
+                                           GNCImportMainMatcher *info,
+                                           gboolean show_edit_actions);
 static gboolean gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
                                                   GdkEvent *event,
                                                   GNCImportMainMatcher *info);
@@ -456,6 +457,11 @@ gnc_gen_trans_list_show_all (GNCImportMainMatcher *info)
     // Set initial state of Append checkbox to same as last import for this account.
     // Get the import account from the first split in first transaction.
     temp_trans_list = info->temp_trans_list;
+    if (!temp_trans_list)
+    {
+        gnc_info_dialog (GTK_WINDOW (info->main_widget), _("No new transactions were found in this import."));
+        return;
+    }
     trans_info = temp_trans_list->data;
     first_split = gnc_import_TransInfo_get_fsplit (trans_info);
     account = xaccSplitGetAccount(first_split);
@@ -879,6 +885,119 @@ gnc_gen_trans_assign_transfer_account_to_selection_cb (GtkMenuItem *menuitem,
     LEAVE("");
 }
 
+typedef enum
+{
+    DESCRIPTION,
+    MEMO,
+    NOTES,
+} edit_field;
+
+static void
+gnc_gen_trans_edit_fields (GtkMenuItem *menuitem, GNCImportMainMatcher *info,
+                           edit_field field)
+{
+    GtkTreeView *treeview;
+    GtkTreeSelection *selection;
+    GtkTreeModel *model;
+    GList *selected_rows;
+    GList *refs = NULL;
+    GtkTreeStore* store;
+    GNCImportTransInfo *trans_info;
+    Transaction* trans;
+    GtkTreeIter iter;
+
+    g_return_if_fail (info != NULL);
+    ENTER("assign_transfer_account_to_selection_cb");
+
+    treeview = GTK_TREE_VIEW(info->view);
+    model = gtk_tree_view_get_model (treeview);
+    store  = GTK_TREE_STORE (model);
+    selection = gtk_tree_view_get_selection (treeview);
+    selected_rows = gtk_tree_selection_get_selected_rows (selection, &model);
+
+    if (!selected_rows)
+    {
+        LEAVE ("No selected rows");
+        return;
+    }
+
+    if (selected_rows->next)
+    {
+        LEAVE ("User selected multiple rows, not supported");
+        return;
+    }
+
+    g_return_if_fail (gtk_tree_model_get_iter (model, &iter,
+                                               selected_rows->data));
+
+    gtk_tree_model_get (model, &iter, DOWNLOADED_COL_DATA,
+                        &trans_info, -1);
+    trans = gnc_import_TransInfo_get_trans (trans_info);
+
+    switch (field)
+    {
+        case DESCRIPTION:
+        {
+            char* new_field =
+                gnc_input_dialog_with_entry(info->main_widget, "",
+                                            _("Enter new Description"),
+                                            xaccTransGetDescription (trans));
+            if (!new_field) break;
+            xaccTransSetDescription (trans, new_field);
+            gtk_tree_store_set (store, &iter, DOWNLOADED_COL_DESCRIPTION,
+                                new_field, -1);
+            g_free (new_field);
+            break;
+        }
+        case MEMO:
+        {
+            Split *first_split =
+                gnc_import_TransInfo_get_fsplit (trans_info);
+            char *new_field =
+                gnc_input_dialog_with_entry(info->main_widget, "",
+                                            _("Enter new Memo"),
+                                            xaccSplitGetMemo (first_split));
+            if (!new_field) break;
+            xaccSplitSetMemo (first_split, new_field);
+            gtk_tree_store_set (store, &iter,
+                                DOWNLOADED_COL_MEMO, new_field, -1);
+            g_free (new_field);
+            break;
+        }
+        case NOTES:
+        {
+            char* new_field =
+                gnc_input_dialog_with_entry(info->main_widget, "",
+                                            _("Enter new Notes"),
+                                            xaccTransGetNotes (trans));
+            if (!new_field) break;
+            xaccTransSetNotes (trans, new_field);
+            g_free (new_field);
+            break;
+        }
+    }
+    g_list_free_full (selected_rows, (GDestroyNotify)gtk_tree_path_free);
+    LEAVE("");
+}
+
+static void
+gnc_gen_trans_edit_description_cb (GtkMenuItem *menuitem, GNCImportMainMatcher *info)
+{
+    gnc_gen_trans_edit_fields (menuitem, info, DESCRIPTION);
+}
+
+static void
+gnc_gen_trans_edit_memo_cb (GtkMenuItem *menuitem, GNCImportMainMatcher *info)
+{
+    gnc_gen_trans_edit_fields (menuitem, info, MEMO);
+}
+
+static void
+gnc_gen_trans_edit_notes_cb (GtkMenuItem *menuitem, GNCImportMainMatcher *info)
+{
+    gnc_gen_trans_edit_fields (menuitem, info, NOTES);
+}
+
 static void
 gnc_gen_trans_row_activated_cb (GtkTreeView *treeview,
                                 GtkTreePath *path,
@@ -966,7 +1085,8 @@ gnc_gen_trans_row_changed_cb (GtkTreeSelection *selection,
 static void
 gnc_gen_trans_view_popup_menu (GtkTreeView *treeview,
                                GdkEvent *event,
-                               GNCImportMainMatcher *info)
+                               GNCImportMainMatcher *info,
+                               gboolean show_edit_actions)
 {
     GtkWidget *menu, *menuitem;
     GdkEventButton *event_button;
@@ -981,6 +1101,33 @@ gnc_gen_trans_view_popup_menu (GtkTreeView *treeview,
                       info);
     DEBUG("Callback to assign destination account to selection connected");
     gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+    
+    if (show_edit_actions)
+    {
+        menuitem = gtk_menu_item_new_with_label (
+                                                 _("Edit description."));
+        g_signal_connect (menuitem, "activate",
+                          G_CALLBACK (gnc_gen_trans_edit_description_cb),
+                          info);
+        DEBUG("Callback to edit description");
+        gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+        
+        menuitem = gtk_menu_item_new_with_label (
+                                                 _("Edit memo."));
+        g_signal_connect (menuitem, "activate",
+                          G_CALLBACK (gnc_gen_trans_edit_memo_cb),
+                          info);
+        DEBUG("Callback to edit memo");
+        gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+        
+        menuitem = gtk_menu_item_new_with_label (
+                                                 _("Edit notes."));
+        g_signal_connect (menuitem, "activate",
+                          G_CALLBACK (gnc_gen_trans_edit_notes_cb),
+                          info);
+        DEBUG("Callback to edit notes");
+        gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+    }
     gtk_widget_show_all (menu);
     event_button = (GdkEventButton *) event;
     /* Note: event can be NULL here when called from view_onPopupMenu; */
@@ -1012,14 +1159,14 @@ gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
             selection = gtk_tree_view_get_selection (treeview);
             count = gtk_tree_selection_count_selected_rows (selection);
             if (count > 1)
-                gnc_gen_trans_view_popup_menu (treeview, event, info);
+                gnc_gen_trans_view_popup_menu (treeview, event, info, FALSE);
             else if (count > 0)
             {
                 GList* selected;
                 GtkTreeModel *model;
                 selected = gtk_tree_selection_get_selected_rows (selection, &model);
                 if (get_action_for_path (selected->data, model) == GNCImport_ADD)
-                    gnc_gen_trans_view_popup_menu (treeview, event, info);
+                    gnc_gen_trans_view_popup_menu (treeview, event, info, TRUE);
                 g_list_free_full (selected, (GDestroyNotify)gtk_tree_path_free);
             }
             LEAVE("return TRUE");
@@ -1040,7 +1187,7 @@ gnc_gen_trans_onPopupMenu_cb (GtkTreeView *treeview,
     selection = gtk_tree_view_get_selection (treeview);
     if (gtk_tree_selection_count_selected_rows (selection) > 0)
     {
-      gnc_gen_trans_view_popup_menu (treeview, NULL, info);
+      gnc_gen_trans_view_popup_menu (treeview, NULL, info, TRUE);
       LEAVE ("TRUE");
       return TRUE;
     }
@@ -1893,7 +2040,7 @@ static void
 match_helper (Split* data, match_struct* s)
 {
     split_find_match (s->transaction_info, data,
-                      s->display_threshold, 
+                      s->display_threshold,
                       s->date_threshold,
                       s->date_not_threshold,
                       s->fuzzy_amount);
