@@ -24,8 +24,47 @@
 ;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define-module (gnucash report html-chart))
+
+(use-modules (gnucash core-utils))
 (use-modules (gnucash json builder))            ;for building JSON options
+(use-modules (gnucash report html-utilities))
 (use-modules (srfi srfi-9))
+(use-modules (ice-9 match))
+
+;; html-chart.scm
+
+(export gnc:html-chart?)
+(export gnc:make-html-chart)
+(export gnc:html-chart-data)
+(export gnc:html-chart-set-data!)
+(export gnc:html-chart-width)
+(export gnc:html-chart-set-width!)
+(export gnc:html-chart-height)
+(export gnc:html-chart-set-height!)
+(export gnc:html-chart-type)
+(export gnc:html-chart-set-type!)
+(export gnc:html-chart-title)
+(export gnc:html-chart-get)
+(export gnc:html-chart-set!)
+(export gnc:html-chart-currency-iso)
+(export gnc:html-chart-set-currency-iso!)
+(export gnc:html-chart-currency-symbol)
+(export gnc:html-chart-set-currency-symbol!)
+(export gnc:html-chart-format-style)
+(export gnc:html-chart-set-format-style!)
+(export gnc:html-chart-render)
+(export gnc:html-chart-set-custom-x-axis-ticks?!)
+(export gnc:html-chart-set-title!)
+(export gnc:html-chart-set-data-labels!)
+(export gnc:html-chart-set-axes-display!)
+(export gnc:html-chart-set-custom-y-axis-ticks?!)
+(export gnc:html-chart-clear-data-series!)
+(export gnc:html-chart-set-x-axis-label!)
+(export gnc:html-chart-set-stacking?!)
+(export gnc:html-chart-set-grid?!)
+(export gnc:html-chart-set-y-axis-label!)
+(export gnc:html-chart-add-data-series!)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -33,8 +72,6 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(use-modules (ice-9 match))
-
 ;; nested-alist-set! parameters are
 ;; lst - a nested alist e.g. (list (cons 'key1 'val1)
 ;;                                 (cons 'key2 (list (cons 'key2-sub1 'val2a))))
@@ -109,13 +146,14 @@
 
 (define-record-type <html-chart>
   (make-html-chart width height chart-options currency-iso
-                   currency-symbol custom-x-axis-ticks? custom-y-axis-ticks?)
+                   currency-symbol format-style custom-x-axis-ticks? custom-y-axis-ticks?)
   html-chart?
   (width html-chart-width html-chart-set-width)
   (height html-chart-height html-chart-set-height)
   (chart-options html-chart-chart-options html-chart-set-chart-options)
   (currency-iso html-chart-currency-iso html-chart-set-currency-iso)
   (currency-symbol html-chart-currency-symbol html-chart-set-currency-symbol)
+  (format-style html-chart-format-style html-chart-set-format-style)
   (custom-x-axis-ticks? html-chart-custom-x-axis-ticks?
                         html-chart-set-custom-x-axis-ticks?)
   (custom-y-axis-ticks? html-chart-custom-y-axis-ticks?
@@ -131,6 +169,8 @@
 (define gnc:html-chart-set-currency-iso! html-chart-set-currency-iso)
 (define gnc:html-chart-currency-symbol html-chart-currency-symbol)
 (define gnc:html-chart-set-currency-symbol! html-chart-set-currency-symbol)
+(define gnc:html-chart-format-style html-chart-format-style)
+(define gnc:html-chart-set-format-style! html-chart-set-format-style)
 (define gnc:html-chart-custom-x-axis-ticks? html-chart-custom-x-axis-ticks?)
 (define gnc:html-chart-set-custom-x-axis-ticks?! html-chart-set-custom-x-axis-ticks?)
 (define gnc:html-chart-custom-y-axis-ticks? html-chart-custom-y-axis-ticks?)
@@ -155,6 +195,8 @@
                  (cons 'datasets #())))
     (cons 'options (list
                     (cons 'maintainAspectRatio #f)
+                    (cons 'animation (list
+                                      (cons 'duration 0)))
                     (cons 'chartArea (list
                                       (cons 'backgroundColor "#fffdf6")))
                     (cons 'legend (list
@@ -217,6 +259,7 @@
                                   (cons 'text ""))))))
    "XXX"     ;currency-iso
    "\u00A4"  ;currency-symbol
+   "currency";format-style
    #t        ;custom x-axis ticks?
    #t        ;custom y-axis ticks?
    ))
@@ -230,17 +273,16 @@
 (define (gnc:html-chart-title chart)
   (gnc:html-chart-get chart '(options title text)))
 
-(define-public (gnc:html-chart-set-title! chart title)
+(define (gnc:html-chart-set-title! chart title)
   (gnc:html-chart-set! chart '(options title text) title))
 
-(define-public (gnc:html-chart-set-data-labels! chart labels)
+(define (gnc:html-chart-set-data-labels! chart labels)
   (gnc:html-chart-set! chart '(data labels) labels))
 
-(define-public (gnc:html-chart-set-axes-display! chart display?)
+(define (gnc:html-chart-set-axes-display! chart display?)
   (gnc:html-chart-set! chart '(options scales xAxes (0) display) display?)
   (gnc:html-chart-set! chart '(options scales yAxes (0) display) display?))
 
-(export gnc:html-chart-add-data-series!)
 ;; e.g.:
 ;; (gnc:html-chart-add-data-series! chart "label" list-of-numbers color
 ;;  'fill #t
@@ -265,29 +307,29 @@
                          (cons 'backgroundColor (list-to-vec color))
                          (cons 'borderColor (list-to-vec color)))))
     (match rest
-      (() (gnc:html-chart-set!
-           chart '(data datasets)
-           (list->vector
-            (append (vector->list
-                     (or (gnc:html-chart-get chart '(data datasets)) #()))
-                    (list newseries)))))
+      (() (let* ((old-vec (gnc:html-chart-get chart '(data datasets)))
+                 (old-len (vector-length old-vec))
+                 (new-vec (make-vector (1+ old-len))))
+            (vector-move-left! old-vec 0 old-len new-vec 0)
+            (vector-set! new-vec old-len newseries)
+            (gnc:html-chart-set! chart '(data datasets) new-vec)))
       ((key val . rest) (loop rest (assq-set! newseries key (list-to-vec val)))))))
 
-(define-public (gnc:html-chart-clear-data-series! chart)
+(define (gnc:html-chart-clear-data-series! chart)
   (gnc:html-chart-set! chart '(data datasets) #()))
 
-(define-public (gnc:html-chart-set-x-axis-label! chart label)
+(define (gnc:html-chart-set-x-axis-label! chart label)
   (gnc:html-chart-set! chart '(options scales xAxes (0) scaleLabel labelString) label))
 
-(define-public (gnc:html-chart-set-stacking?! chart stack?)
+(define (gnc:html-chart-set-stacking?! chart stack?)
   (gnc:html-chart-set! chart '(options scales xAxes (0) stacked) stack?)
   (gnc:html-chart-set! chart '(options scales yAxes (0) stacked) stack?))
 
-(define-public (gnc:html-chart-set-grid?! chart grid?)
+(define (gnc:html-chart-set-grid?! chart grid?)
   (gnc:html-chart-set! chart '(options scales xAxes (0) gridLines display) grid?)
   (gnc:html-chart-set! chart '(options scales yAxes (0) gridLines display) grid?))
 
-(define-public (gnc:html-chart-set-y-axis-label! chart label)
+(define (gnc:html-chart-set-y-axis-label! chart label)
   (gnc:html-chart-set! chart '(options scales yAxes (0) scaleLabel labelString) label))
 
 (define (gnc:html-chart-get chart path)
@@ -305,10 +347,10 @@
 // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/toLocaleString
 var toLocaleStringSupportsOptions = (typeof Intl == 'object' && Intl && typeof Intl.NumberFormat == 'function');
 
-// format a number e.g. 2.5 into monetary e.g. \"$2.50\"
+// format a number e.g. 2.5 into monetary e.g. \"$2.50\" or other style formsty
 function numformat(amount) {
   if (toLocaleStringSupportsOptions) {
-      return amount.toLocaleString(undefined, {style:'currency', currency:curriso});
+      return amount.toLocaleString(undefined, {style:formsty, currency:curriso});
   } else {
       return currsym + amount.toLocaleString();
   }
@@ -329,7 +371,7 @@ function tooltipLabel(tooltipItem,data) {
 }
 
 function tooltipTitle(array,data) {
-  return chartjsoptions.data.labels[array[0].index]; }
+  return data.labels[array[0].index]; }
 
 // draw the background color
 Chart.pluginService.register({
@@ -408,8 +450,7 @@ document.getElementById(chartid).onclick = function(evt) {
          ;; clashing on multi-column reports
          (id (symbol->string (gensym "chart"))))
 
-    (push (gnc:html-js-include
-           (gnc-path-find-localized-html-file "chartjs/Chart.bundle.min.js")))
+    (push (gnc:html-js-include "chartjs/Chart.bundle.min.js"))
 
     ;; the following hidden h3 is used to query style and copy onto chartjs
     (push "<h3 style='display:none'></h3>")
@@ -422,6 +463,7 @@ document.getElementById(chartid).onclick = function(evt) {
     (push (format #f "<script id='script-~a'>\n" id))
     (push (format #f "var curriso = ~s;\n" (gnc:html-chart-currency-iso chart)))
     (push (format #f "var currsym = ~s;\n" (gnc:html-chart-currency-symbol chart)))
+    (push (format #f "var formsty = ~s;\n" (gnc:html-chart-format-style chart)))
     (push (format #f "var chartid = ~s;\n" id))
     (push (format #f "var jumpid = 'jump-~a';\n" id))
     (push (format #f "var loadstring = ~s;\n" (G_ "Load")))
